import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="Kyak2-Void",
    version="0.2.0",
    author="UnbalancedSkunk",
    author_email="turkishanhur@gmail.com",
    description="Void Linux Openbox(WM-Window Manager) Logout screen with Tkinter",
    long_description=long_description,
    long_description_content_type="text/markdown",
    license="GPLv3",
    url="https://github.com/UnbalancedSkunk/Kyak2",
    project_urls={
        "Bug Tracker": "https://github.com/UnbalancedSkunk/Kyak2",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: POSIX :: Linux",
    ],
    package_dir={"": "src"},
    packages=setuptools.find_packages(where="src"),
    python_requires=">=3.6",
)


#!/usr/bin/env python3
# -*- coding: utf-8 -*
from tkinter import *
import os
veri = Tk()
veri.title('KYAK2-Void')
veri.geometry('80x230')
veri.configure(bg='#252726')
veri.maxsize(80,230)
veri.minsize(80,230)


def deger1():
    os.system("loginctl suspend")
    os.system("xscreensaver-command -l")
def deger2():
    os.system("xscreensaver-command -l")
def deger3():
    os.system("loginctl reboot")
def deger4():
    os.system("loginctl poweroff")
def deger5():
    os.system("openbox --exit")	
buton = Button(veri,text='Suspend',fg='#F0E68C',bg='#252726',command=deger1)
buton.place(x=0, y=50)
buton2 = Button(veri,text='Lock',fg='#C0C0C0',bg='#252726',command=deger2)
buton2.place(x=0, y=0)
buton3 = Button(veri,text='Reboot',fg='#00FA9A',bg='#252726',command=deger3)
buton3.place(x=0, y=100)
buton4 = Button(veri,text='Poweroff',fg='#B22222',bg='#252726',command=deger4)
buton4.place(x=0, y=150)
buton5 = Button(veri,text='Log-Out',fg='crimson',bg='#252726',command=deger5)
buton5.place(x=0, y=200)

 

veri.mainloop()
sys.exit(veri_exec())


#!/usr/bin/env python3
# -*- coding: utf-8 -*
from tkinter import *
import os
veri = Tk()
veri.title('Kyak2-Void-guinstaller')
veri.geometry('400x225')
veri.configure(bg='#252726')
veri.maxsize(400,225)
veri.minsize(400,225)


Label(text="Welcome to my app it needs Xterm terminal software\nand sudo permission to copy files needed locations\nTwo times password is asked for Menu Launcher\nOne time for Terminal Shortcut\nEnter password wait 5 sec and close.",fg='#00FA9A',bg='#252726').place(x=0,y=0)


def deger1():
    os.system("xterm -hold -e sudo cp Kyak2-Void.py /usr/share/applications/")
    os.system("xterm -hold -e sudo cp Kyak2-Void.desktop /usr/share/applications/")
def deger2():
    os.system("xterm -hold -e sudo cp Kyak2-Void.py /usr/bin/")
def deger3():
    os.system("xterm -hold -e sudo rm /usr/share/applications/Kyak2-Void.py")
    os.system("xterm -hold -e sudo rm /usr/share/applications/Kyak2-Void.desktop")
def deger4():
    os.system("xterm -hold -e sudo rm /usr/bin/Kyak2-Void.py")
    	
buton = Button(veri,text='Menu Launcher',fg='crimson',bg='#252726',command=deger1)
buton.place(x=30, y=100)
buton2 = Button(veri,text='Terminal Shortcut',fg='crimson',bg='#252726',command=deger2)
buton2.place(x=175, y=100)
buton3 = Button(veri,text='Launcher Uninstaller',fg='crimson',bg='#252726',command=deger3)
buton3.place(x=30, y=160)
buton4 = Button(veri,text='Shortcut Uninstaller',fg='crimson',bg='#252726',command=deger4)
buton4.place(x=175, y=160)




veri.mainloop()